package com.cpms.project.safety.service;


import com.cpms.project.safety.domain.TSafetyEyeWasher;

import java.util.List;

/**
 * 洗眼器Service接口
 * 
 * @author ruoyi
 * @date 2023-05-25
 */
public interface ITSafetyEyeWasherService 
{
    /**
     * 查询洗眼器
     * 
     * @param id 洗眼器主键
     * @return 洗眼器
     */
    public TSafetyEyeWasher selectTSafetyEyeWasherById(Long id);

    /**
     * 查询洗眼器列表
     * 
     * @param tSafetyEyeWasher 洗眼器
     * @return 洗眼器集合
     */
    public List<TSafetyEyeWasher> selectTSafetyEyeWasherList(TSafetyEyeWasher tSafetyEyeWasher);

    /**
     * 新增洗眼器
     * 
     * @param tSafetyEyeWasher 洗眼器
     * @return 结果
     */
    public int insertTSafetyEyeWasher(TSafetyEyeWasher tSafetyEyeWasher);

    /**
     * 修改洗眼器
     * 
     * @param tSafetyEyeWasher 洗眼器
     * @return 结果
     */
    public int updateTSafetyEyeWasher(TSafetyEyeWasher tSafetyEyeWasher);

    /**
     * 批量删除洗眼器
     * 
     * @param ids 需要删除的洗眼器主键集合
     * @return 结果
     */
    public int deleteTSafetyEyeWasherByIds(Long[] ids);

    /**
     * 删除洗眼器信息
     * 
     * @param id 洗眼器主键
     * @return 结果
     */
    public int deleteTSafetyEyeWasherById(Long id);
}
